Supvisors status

Name | State | Supervisor | Description | Load | MEM | CPU | Actions | Log
--- | --- | --- | --- | --- | --- | --- | --- | ---
Name | State | Supervisor | Description | Load | MEM | CPU | Actions | Log
Name | State | Supervisor | Description | 5% | -- | -- | Start | Stop | Restart | Clear | Stdout | Stderr

#### Detailed Statistics -- * on --

CPU
% | Mean % | Slope % | SD %
--- | --- | --- | ---
-- | -- | -- | --

MEM
% | Mean % | Slope % | SD %
--- | --- | --- | ---
-- | -- | -- | --